#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-EGQEfspC3PS4omNKpP9y3p
key:                  persistent-test-2.13.1.3-EGQEfspC3PS4omNKpP9y3p
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  ed864223fe158767f0aeb464bf365648
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-EGQEfspC3PS4omNKpP9y3p
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-3mU9ZiusQQy5d3HGk3bpZl
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN base-4.18.2.1
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7 bytestring-0.11.5.3
    conduit-1.3.6.1-BJxsltXT31mLaWStW2N7GT containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-FxYk9RksUQ4Ah0F04Y4GJN
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-BwFpbURgyw753i0oz3R4fv
    monad-control-1.0.3.1-8wPa0oMkCWR7jw1sOTWw8m
    monad-logger-0.3.42-Kg1sGrh8TOu3fkh5KWL68s mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.0-Dnhf69dRMkN55hIaquPnNu
    quickcheck-instances-0.3.33-DoOzaZyJlsZ2KJLXgPLxXU
    random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    resourcet-1.3.0-1zDmXgfXfhGHcZ53EkSGgY text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-GqSX9ijaX57Je8pYGIG6bu
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

